@@ -32,6 +32,8 @@ from garf_core import report
 from media_similarity import media_similarity_service
 from media_tagging import media, tagging_result
 
+from filonov import previews
+
 MetricInfo: TypeAlias = dict[str, int | float]
 Info: TypeAlias = dict[str, int | float | str | list[str] | None]
 
@@ -115,6 +117,7 @@ class CreativeMap:
     tagging_results: Sequence[tagging_result.TaggingResult],
     extra_info: dict[str, MediaInfo] | None = None,
     fetching_request: dict[str, Any] | None = None,
+    embed_previews: bool = False,
   ) -> CreativeMap:
     """Builds network visualization with injected extra_info."""
     tagging_mapping = {
@@ -124,6 +127,9 @@ class CreativeMap:
       t.hash: t.identifier for t in tagging_results
     }
     media_type = tagging_results[0].type
+    preview_strategy = previews.get_media_preview_strategy(
+      media_type=media_type, embed_previews=embed_previews
+    )
     for node in clustering_results.graph.nodes:
       node_hash = node.get('name', '')
       node_name = tagging_hash_to_identifier_mapping.get(node_hash)
@@ -132,7 +138,10 @@ class CreativeMap:
         if size := node_extra_info.size:
           node['size'] = size
         node['type'] = media_type
-        node['image'] = node_extra_info.media_preview
+        if preview_strategy:
+          node['image'] = preview_strategy(node_extra_info)
+        else:
+          node['image'] = node_extra_info.media_preview
         node['media_path'] = node_extra_info.media_path
         node['label'] = node_extra_info.media_name or 'Unknown'
         node['cluster'] = clustering_results.clusters.get(node_name)
